@@ -9,9 +9,9 @@ use std::fmt;
 use std::iter::Peekable;
 use std::slice::Iter;
 
-use comp_op::CompOp;
-use version_manifest::VersionManifest;
-use version_part::VersionPart;
+use crate::comp_op::CompOp;
+use crate::version_manifest::VersionManifest;
+use crate::version_part::VersionPart;
 
 /// Version struct, which is a representation for a parsed version string.
 ///
@@ -450,15 +450,16 @@ impl<'a> PartialEq for Version<'a> {
     }
 }
 
+#[cfg_attr(tarpaulin, skip)]
 #[cfg(test)]
 mod tests {
     use std::cmp;
 
-    use comp_op::CompOp;
-    use test::test_version::{TEST_VERSIONS, TEST_VERSIONS_ERROR};
-    use test::test_version_set::TEST_VERSION_SETS;
-    use version_manifest::VersionManifest;
-    use version_part::VersionPart;
+    use crate::comp_op::CompOp;
+    use crate::test::test_version::{TEST_VERSIONS, TEST_VERSIONS_ERROR};
+    use crate::test::test_version_set::TEST_VERSION_SETS;
+    use crate::version_manifest::VersionManifest;
+    use crate::version_part::VersionPart;
 
     use super::Version;
 
@@ -662,7 +663,14 @@ mod tests {
             let version_b = Version::from(&entry.1).unwrap();
 
             // Compare them
-            assert_eq!(version_a.compare(&version_b), entry.2.clone());
+            assert_eq!(
+                version_a.compare(&version_b),
+                entry.2.clone(),
+                "Testing that {} is {} {}",
+                &entry.0,
+                &entry.2.sign(),
+                &entry.1
+            );
         }
     }
 
@@ -687,6 +695,23 @@ mod tests {
             .compare_to(&Version::from("1.2.3").unwrap(), &CompOp::Ne,));
     }
 
+    #[test]
+    fn display() {
+        assert_eq!(format!("{}", Version::from("1.2.3").unwrap()), "1.2.3");
+    }
+
+    #[test]
+    fn debug() {
+        assert_eq!(
+            format!("{:?}", Version::from("1.2.3").unwrap()),
+            "[Number(1), Number(2), Number(3)]",
+        );
+        assert_eq!(
+            format!("{:#?}", Version::from("1.2.3").unwrap()),
+            "[\n    Number(\n        1,\n    ),\n    Number(\n        2,\n    ),\n    Number(\n        3,\n    ),\n]",
+        );
+    }
+
     #[test]
     fn partial_cmp() {
         // Compare each version in the version set
